@@ -15,7 +15,7 @@
 #'
 #' @param formula model formula providing the recorded signal intensities with
 #' respect to the nominal analyte concentrations in the form of
-#' \code{signal ~ concentration} or \code{signal ~ concentraion - 1}; model
+#' \code{signal ~ concentration} or \code{signal ~ concentration - 1}; model
 #' formulas are currently restricted to those forms, however, the possibility
 #' to use \code{log} or \code{sqrt} transformed data will be implemented in the
 #' future.
@@ -123,15 +123,12 @@ calibration <- function(formula, data = NULL, blanks = NULL, weights = NULL,
   cal$relerr <- relerr(cal)
   
   if (is.null(weights) & check_assumptions) {
-    swt <- shapiro.test(model$residuals)
-    bpt <- bptest(model)
+    cal$shapiro.test <- shapiro.test(model$residuals)
+    cal$shapiro.test$data.name <- paste0("residuals(", deparse(model$call), ")")
+    cal$bptest <- bptest(model)
+    cal$bptest$data.name <- deparse(formula)
     
-    cat("Check for normality of residuals\n")
-    print(swt)
-    cat("Check for homoscedasticity of residuals\n")
-    print(bpt)
-    
-    if (swt$p.value < 0.05 || bpt$p.value < 0.05)
+    if (cal$shapiro.test$p.value < 0.05 || cal$bptest$p.value < 0.05)
       warning("model assumptions may not be met; double check graphically and ",
               "consider using a weighted model instead")
   }
@@ -152,6 +149,13 @@ print.calibration <- function(x, ...) {
   print(x$blanks)
   cat("\n")
   print(signif(rbind(x$lod, x$loq), 3))
+  if (!is.null(x$shapiro.test) & !is.null(x$bptest)) {
+    cat("\n")
+    cat("Check for normality of residuals:\n")
+    print(x$shapiro.test)
+    cat("Check for homoscedasticity of residuals:\n")
+    print(x$bptest)
+  }
 }
 
 #' @rdname calibration
